@@ -1,5 +1,5 @@
 from .get_gifNimage import get_gifNimage
-print('get_gifNimage(link, file_name_show=False, dict_appearance=False, show_error_logs=False, only_picture_name=False, markdown_name=False)')
+print('def get_gifNimage(link, file_name_show=False, dict_appearance=False, show_error_logs=False, only_picture_name=False, markdown_name=False, menu=False, more_info=False)')
 
 """
 For unknown reason when I rename CHANGELOG.TXT to CHANGELOG.md -
